@@ -67,10 +67,11 @@ class TrainCache(Generic[ModelT]):
         return np.array(partial_lossseq_list).sum(axis=0).tolist()
 
     @property
-    def min_validate_loss(self) -> float:
+    def min_valid_loss(self) -> Tuple[int, float]:
+        """get index and valid loss value if loss corresponding best_model"""
         lossseq = self.reduce_to_lossseq(self.validate_lossseq_table)
-        min_loss_sofar = min(lossseq)
-        return min_loss_sofar
+        index = int(np.argmin(lossseq))
+        return index, lossseq[index]
 
     @staticmethod
     def train_result_base_path(project_path: Path) -> Path:
@@ -194,8 +195,9 @@ class TrainCache(Generic[ModelT]):
             self.validate_lossseq_table[key].append(validate_loss_dict[key])
 
         validate_loss_list = self.reduce_to_lossseq(self.validate_lossseq_table)
-        require_update_model = validate_loss_list[-1] == self.min_validate_loss
-        if require_update_model:
+        require_update = len(validate_loss_list) - 1 == self.min_valid_loss[0]
+        if require_update:
+            assert validate_loss_list[-1] == self.min_valid_loss[1]
             self.best_model = model
             self.save(project_path)
 
@@ -271,18 +273,32 @@ class TrainCache(Generic[ModelT]):
         **kwargs,
     ) -> "TrainCache[ModelT]":
         tcache_list = cls.load_all(project_path, model_type, **kwargs)
-        tcaceh_list_sorted = sorted(tcache_list, key=lambda tcache: tcache.min_validate_loss)
+        tcaceh_list_sorted = sorted(tcache_list, key=lambda tcache: tcache.min_valid_loss[1])
         return tcaceh_list_sorted[0]
 
-    def visualize(self, fax: Optional[Tuple] = None):
-        fax = plt.subplots() if fax is None else fax
-        fig, ax = fax
+    def visualize(self) -> Tuple:
+        fig, axes = plt.subplots(1, 3)
+        ax = axes[0]
         train_lossseq = self.reduce_to_lossseq(self.train_lossseq_table)
         valid_lossseq = self.reduce_to_lossseq(self.validate_lossseq_table)
         ax.plot(train_lossseq)
         ax.plot(valid_lossseq)
         ax.set_yscale("log")
         ax.legend(["train", "valid"])
+        ax.title.set_text("valid and train total loss")
+
+        keys = list(self.validate_lossseq_table.keys())
+
+        for key in keys:
+            axes[1].plot(self.train_lossseq_table[key])
+            axes[2].plot(self.validate_lossseq_table[key])
+            axes[1].title.set_text("each train loss")
+            axes[2].title.set_text("each valid loss")
+        for ax in [axes[1], axes[2]]:
+            ax.legend(keys)
+            ax.set_yscale("log")
+
+        return (fig, axes)
 
 
 def train(
@@ -295,6 +311,7 @@ def train(
     log_package_version_info(logger, mohou)
     log_text_with_box(logger, "train log")
     logger.info("train start with config: {}".format(config))
+    logger.info("model cache path: {}".format(tcache.cache_path(project_path)))
 
     model = tcache.best_model
 
